@@ -13,6 +13,7 @@ from operator import itemgetter
 import pytest
 import requests
 
+import univention.admin.modules
 from univention.admin.rest.client import (
     UDM as UDMClient, Forbidden, PreconditionFailed, Unauthorized, UnprocessableEntity,
 )
@@ -23,6 +24,9 @@ from univention.testing.udm import UDM, UCSTestUDM_CreateUDMObjectFailed
 from univention.testing.utils import UCSTestDomainAdminCredentials
 
 
+univention.admin.modules.update()
+
+
 if ucr.is_true('ad/member'):
     # REST server needs to reload UCR variables for "Domain Adminis" group name
     subprocess.call(['service', 'univention-directory-manager-rest', 'restart'])
@@ -70,6 +74,12 @@ def test_authentication(udm):
     udm_client.get('users/user')
 
 
+@pytest.mark.parametrize('module', [n for n, m in univention.admin.modules.modules.items() if not getattr(m, 'virtual', False) and 'add' in m.operations])
+def test_all_module_descriptions(module, udm_client):
+    mod = udm_client.get(module)
+    mod.new()
+
+
 def test_etag_after_create_via_post(udm, udm_client, random_string):
     """make sure POST a new user creates a etag"""
     User = udm_client.get('users/user')
@@ -231,10 +241,9 @@ def test_special_characters_in_dn(name, udm_client, udm_rest):
     assert obj
 
 
-@locale_available()
 @pytest.mark.parametrize('language,error_message', [
-    ('en-US', 'The property gecos has an invalid value: Field must only contain ASCII characters!'),
-    ('de-DE', 'Die Eigenschaft gecos hat einen ungültigen Wert: Der Wert darf nur ASCII Buchstaben enthalten!'),
+    pytest.param('en-US', 'The property gecos has an invalid value: GECOS: Field must only contain ASCII characters!', marks=locale_available("en_US")),
+    pytest.param('de-DE', 'Die Eigenschaft gecos hat einen ungültigen Wert: GECOS: Der Wert darf nur ASCII Buchstaben enthalten!', marks=locale_available("de_DE")),
 ])
 def test_translation(language, error_message):
     with UDM(language=language) as udm:
