@@ -38,6 +38,7 @@ from dataclasses import dataclass
 
 from playwright.sync_api import Locator, Page, expect
 
+from univention.config_registry import ucr
 from univention.lib.i18n import Translation
 from univention.testing.browser.lib import UMCBrowserTest
 
@@ -136,7 +137,7 @@ class GenericUDMModule(object):
         self.page: Page = tester.page
         self.module_name: str = module_name
 
-    def navigate(self, username='Administrator', password='univention') -> None:
+    def navigate(self, username='Administrator', password=ucr.get('tests/domainadmin/pwd', 'univention')) -> None:
         self.tester.login(username, password)
         self.tester.open_module(self.module_name)
 
@@ -149,11 +150,15 @@ class GenericUDMModule(object):
         """
         self.page.get_by_role('button', name=_('Add')).click()
 
+        if self.page.get_by_text(_('This UCS system is part of an Active Directory domain')).is_visible():
+            self.page.get_by_role('button', name=_('Next')).click()
         return AddObjectDialog(self.tester, self.page.get_by_role('dialog'))
 
     def add_object_detail_view(self) -> DetailsView:
         """See `add_object_dialog` for details"""
         self.page.get_by_role('button', name=_('Add')).click()
+        if self.page.get_by_text(_('This UCS system is part of an Active Directory domain')).is_visible():
+            self.page.get_by_role('button', name=_('Next')).click()
         return DetailsView(self.tester)
 
     def open_details(self, name: str) -> DetailsView:
@@ -268,7 +273,8 @@ class UserModule(GenericUDMModule):
         add_object.fill_field(f"{_('Password')} *", password, exact=True)
         add_object.fill_field(f"{_('Password (retype)')} *", password, exact=True)
         add_object.finish('Create User')
-
+        if ucr.is_true('ad/member'):
+            return CreatedItem(first_name + ' ' + last_name)
         return CreatedItem(name)
 
     def copy_user(self, original_name: str, name: str, last_name: str = 'last_name', password: str = 'univention') -> None:
